@@ -190,6 +190,7 @@ def _post_processing(
     skip_tests: bool,
     python: Optional[str],
     github_token: Optional[str],
+    https_origin: bool,
 ) -> None:
     """Apply post processing steps after rendering the template wit Copier.
 
@@ -201,6 +202,7 @@ def _post_processing(
             processing.
         github_token: Github Token to push the newly created repository to
             Github. The token must have writing permissions.
+        https_origin: force the origin to be an HTTPS URL.
     """
     git = importlib.import_module(
         "python_whiteprint.git",
@@ -266,11 +268,15 @@ def _post_processing(
             repository,
             project_slug=copier_answers["project_slug"],
             github_token=github_token,
+            github_login=copier_answers["github_user"],
             labels=destination / LABEL_FILE,
         )
         git.protect_repository(
+            repository,
             project_slug=copier_answers["project_slug"],
             github_token=github_token,
+            github_login=copier_answers["github_user"],
+            https_origin=https_origin,
         )
 
 
@@ -511,6 +517,14 @@ _option_github_token = params.Option(
     envvar="WHITEPRINT_GITHUB_TOKEN",
 )
 """see `python_whiteprint.cli.init.init` option `github_token`."""
+_option_https_origin = params.Option(
+    os.environ.get("WHITEPRINT_HTTPS_ORIGIN", False),
+    "--https-origin",
+    "-H",
+    envvar="WHITEPRINT_HTTPS_ORIGIN",
+    help=_("Force the origin to be an https URL."),
+)
+"""see `python_whiteprint.cli.init.init` option `https_origin`."""
 
 
 @beartype
@@ -548,6 +562,7 @@ def init(  # pylint: disable=too-many-locals
     user_defaults: Optional[pathlib.Path] = _option_user_defaults,
     python: Optional[str] = _option_python,
     github_token: Optional[str] = _option_github_token,
+    https_origin: bool = _option_https_origin,
 ) -> None:
     """Initalize a new Python project.
 
@@ -583,6 +598,7 @@ def init(  # pylint: disable=too-many-locals
             processing.
         github_token: Github Token to push the newly created repository to
             Github. The token must have writing permissions.
+        https_origin: force the origin to be an HTTPS URL.
     """
     data_dict = {} if no_data or data is None else read_yaml(data)
     data_dict.update(
@@ -620,4 +636,5 @@ def init(  # pylint: disable=too-many-locals
         skip_tests=skip_tests,
         python=python,
         github_token=github_token,
+        https_origin=https_origin,
     )
